package org.openvpms.archetype.rules.finance.account;

import org.openvpms.archetype.rules.act.ActCopyHandler;
import org.openvpms.component.business.domain.im.archetype.descriptor.ArchetypeDescriptor;
import org.openvpms.component.business.domain.im.archetype.descriptor.NodeDescriptor;

/**
 * Base class for customer act reversal handlers.
 *
 * @author Tim Anderson
 */
public abstract class AbstractCustomerActReversalHandler extends ActCopyHandler {

    /**
     * Constructs an {@link AbstractCustomerActReversalHandler}.
     *
     * @param archetypeMap a list of archetype pairs, indicating the archetype to map from and to. If the 'to' archetype
     *                     is null, then any instance of the 'from' is ignored
     */
    AbstractCustomerActReversalHandler(String[][] archetypeMap) {
        super(archetypeMap);
    }

    /**
     * Helper to determine if a node is copyable.
     *
     * @param archetype the archetype descriptor
     * @param node      the node descriptor
     * @param source    if {@code true} the node is the source; otherwise its the target
     * @return {@code true} if the node is copyable; otherwise {@code false}
     */
    @Override
    protected boolean isCopyable(ArchetypeDescriptor archetype, NodeDescriptor node, boolean source) {
        String name = node.getName();
        if ("credit".equals(name) || "allocatedAmount".equals(name)
            || "accountBalance".equals(name) || "allocation".equals(name) || "reversals".equals(name)
            || "reverses".equals(name) || "hide".equals(name)) {
            return false;
        } else {
            return super.isCopyable(archetype, node, source);
        }
    }
}
