/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.archetype.test.builder.customer.account;

import org.openvpms.archetype.rules.finance.account.CustomerAccountRules;
import org.openvpms.component.service.archetype.ArchetypeService;

/**
 * Factory for creating customer account acts.
 *
 * @author Tim Anderson
 */
public class TestCustomerAccountFactory {

    /**
     * The archetype service.
     */
    private final ArchetypeService service;

    /**
     * The customer account rules.
     */
    private final CustomerAccountRules rules;

    /**
     * Constructs a {@link TestCustomerAccountFactory}.
     *
     * @param service the archetype service
     * @param rules   the customer account rules
     */
    public TestCustomerAccountFactory(ArchetypeService service, CustomerAccountRules rules) {
        this.service = service;
        this.rules = rules;
    }

    /**
     * Returns a builder for a new customer invoice.
     *
     * @return a customer invoice builder
     */
    public TestInvoiceBuilder newInvoice() {
        return new TestInvoiceBuilder(service);
    }

    /**
     * Returns a builder for a new estimate.
     *
     * @return an estimate builder
     */
    public TestEstimateBuilder newEstimate() {
        return new TestEstimateBuilder(service, rules);
    }

    /**
     * Returns a builder for a new estimate item.
     *
     * @return an estimate item builder
     */
    public TestEstimateItemBuilder newEstimateItem() {
        return new TestEstimateItemBuilder(null, service, rules);
    }

}
