/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.archetype.test.builder.practice;

import org.openvpms.component.model.party.Party;
import org.openvpms.component.service.archetype.ArchetypeService;

/**
 * Builder for <em>party.organisationPractice</em> instances, for testing purposes.
 *
 * @author Tim Anderson
 */
public class TestPracticeFactory {

    /**
     * The archetype service.
     */
    private final ArchetypeService service;

    /**
     * Constructs a {@link TestPracticeFactory}.
     *
     * @param service the archetype service
     */
    public TestPracticeFactory(ArchetypeService service) {
        this.service = service;
    }

    /**
     * Creates and saves a practice.
     *
     * @return the practice
     */
    public Party getPractice() {
        return newPractice().build();
    }

    /**
     * Returns a builder for a new practice.
     *
     * @return a practice builder
     */
    public TestPracticeBuilder newPractice() {
        return new TestPracticeBuilder(service);
    }

    /**
     * Creates and saves a practice location.
     *
     * @return the practice location
     */
    public Party createLocation() {
        return newLocation().build();
    }

    /**
     * Returns a builder for a new practice location.
     *
     * @return a practice location builder
     */
    public TestLocationBuilder newLocation() {
        return new TestLocationBuilder(service);
    }
}
