/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.archetype.test.builder.user;

import org.openvpms.component.model.user.User;
import org.openvpms.component.service.archetype.ArchetypeService;

/**
 * Factory for creating users.
 *
 * @author Tim Anderson
 */
public class TestUserFactory {

    /**
     * The archetype service.
     */
    private final ArchetypeService service;

    /**
     * Constructs a {@link TestUserFactory}.
     *
     * @param service the service
     */
    public TestUserFactory(ArchetypeService service) {
        this.service = service;
    }

    /**
     * Creates and saves a user.
     *
     * @return the user
     */
    public User createUser() {
        return newUser().build();
    }

    /**
     * Creates and saves a user.
     *
     * @param firstName the user's first name
     * @param lastName  the user's last name
     * @return the user
     */
    public User createUser(String firstName, String lastName) {
        return newUser().firstName(firstName).lastName(lastName).build();
    }

    /**
     * Creates and saves a clinician.
     *
     * @return the clinician
     */
    public User createClinician() {
        return newUser().clinician().build();
    }

    /**
     * Creates and saves a clinician.
     *
     * @param firstName the clinician's first name
     * @param lastName  the clinician's last name
     * @return the clinician
     */
    public User createClinician(String firstName, String lastName) {
        return newUser().firstName(firstName).lastName(lastName).clinician().build();
    }

    /**
     * Creates and saves a clinician.
     *
     * @param title     the clinician title code
     * @param firstName the clinician's first name
     * @param lastName  the clinician's last name
     * @return the clinician
     */
    public User createClinician(String title, String firstName, String lastName) {
        return newUser().title(title).firstName(firstName).lastName(lastName).clinician().build();
    }

    /**
     * Creates and saves an administrator.
     *
     * @return the administrator
     */
    public User createAdministrator() {
        return newUser().administrator().build();
    }

    /**
     * Returns a builder for a new user.
     *
     * @return a user builder
     */
    public TestUserBuilder newUser() {
        return new TestUserBuilder(service);
    }
}
