/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.tool.toolbox.db;

import org.openvpms.tool.db.DBTool;
import org.openvpms.tool.toolbox.AbstractCommand;
import org.openvpms.tool.toolbox.config.ConfigProperties;

/**
 * Base class for commands that perform low-level database changes.
 * <p/>
 * These don't use (or can't use) a Spring context.
 *
 * @author Tim Anderson
 */
public abstract class AbstractDBCommand extends AbstractCommand {

    /**
     * The database tool.
     */
    private DBTool tool;

    /**
     * The configuration properties.
     */
    private ConfigProperties properties;

    /**
     * Initialises the command.
     *
     * @throws Exception for any error
     */
    @Override
    protected void init() throws Exception {
        properties = loadProperties();
        checkProperties(properties);
        checkDriver(properties);
        tool = new DBTool(properties.getDriver(), properties.getUrl(), properties.getUsername(),
                          properties.getPassword());
    }

    /**
     * Returns the configuration properties.
     *
     * @return the properties
     */
    protected ConfigProperties getProperties() {
        return properties;
    }

    /**
     * Returns the database tool.
     *
     * @return the database tool
     */
    protected DBTool getTool() {
        return tool;
    }
}
