/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.tool.toolbox.plugin;

import org.openvpms.component.business.service.archetype.rule.IArchetypeRuleService;
import org.openvpms.component.model.entity.Entity;
import org.openvpms.component.query.criteria.CriteriaBuilder;
import org.openvpms.component.query.criteria.CriteriaQuery;
import org.openvpms.component.query.criteria.Root;
import org.openvpms.component.service.archetype.ArchetypeService;
import org.openvpms.tool.toolbox.AbstractApplicationContextCommand;

/**
 * Enables/disables plugins.
 *
 * @author Tim Anderson
 */
abstract class AbstractPluginCommand extends AbstractApplicationContextCommand {

    /**
     * Marks the plugin configuration active/inactive.
     *
     * @param active if {@code true} mark it active, otherwise mark it inactive
     * @return {@code 0} if the configuration exists, {@code 1} if it doesn't
     */
    protected int setActive(boolean active) {
        int result = 1;
        Entity config = getConfig();
        if (config != null) {
            if (config.isActive() != active) {
                config.setActive(active);
                ArchetypeService service = getBean(IArchetypeRuleService.class);
                service.save(config);
                if (active) {
                    System.out.println("Plugins enabled. If OpenVPMS is already running it needs to be restarted.");
                } else {
                    System.out.println("Plugins disabled. If OpenVPMS is already running it needs to be restarted.");
                }
            } else {
                if (active) {
                    System.out.println("Plugins already enabled.");
                } else {
                    System.out.println("Plugins already disabled.");
                }
            }
            result = 0;
        } else {
            System.out.println("Plugins not configured.");
        }
        return result;
    }

    /**
     * Returns the plugin configuration.
     *
     * @return the plugin configuration, or {@code null} if it does not exist
     */
    protected Entity getConfig() {
        ArchetypeService service = getBean(IArchetypeRuleService.class);
        CriteriaBuilder builder = service.getCriteriaBuilder();
        CriteriaQuery<Entity> query = builder.createQuery(Entity.class);
        Root<Entity> from = query.from(Entity.class, "entity.pluginConfiguration");
        query.orderBy(builder.asc(from.get("id")));
        return service.createQuery(query).getFirstResult();
    }
}
