/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.workspace.customer.payment;

import nextapp.echo2.app.Component;
import org.openvpms.archetype.rules.practice.PracticeService;
import org.openvpms.component.business.domain.im.act.Act;
import org.openvpms.component.business.domain.im.act.ActRelationship;
import org.openvpms.component.business.domain.im.party.Party;
import org.openvpms.component.model.bean.IMObjectBean;
import org.openvpms.web.component.im.edit.act.AltModelActRelationshipCollectionEditor;
import org.openvpms.web.component.im.layout.LayoutContext;
import org.openvpms.web.component.property.CollectionProperty;
import org.openvpms.web.system.ServiceHelper;

/**
 * Editor for collections of payment item {@link ActRelationship}s.
 * <p/>
 * This defaults the payment item archetype to the <em>defaultPaymentType</em> of <em>party.organisationPractice</em>
 *
 * @author Tim Anderson
 */
public class PaymentItemRelationshipCollectionEditor extends AltModelActRelationshipCollectionEditor {

    /**
     * The default payment type node of party.organisationPractice.
     */
    private static final String DEFAULT_PAYMENT_TYPE = "defaultPaymentType";

    /**
     * Creates an {@link PaymentItemRelationshipCollectionEditor}.
     *
     * @param property the collection property
     * @param act      the parent act
     * @param context  the layout context
     */
    public PaymentItemRelationshipCollectionEditor(CollectionProperty property, Act act, LayoutContext context) {
        super(property, act, context);
    }

    /**
     * Lays out the component.
     *
     * @param context the layout context
     * @return the component
     */
    @Override
    protected Component doLayout(LayoutContext context) {
        Component component = super.doLayout(context);

        // select the default payment type, if one is defined on the practice
        PracticeService practiceService = ServiceHelper.getBean(PracticeService.class);
        Party practice = practiceService.getPractice();
        if (practice != null) {
            IMObjectBean bean = getBean(practice);
            String archetype = bean.getString(DEFAULT_PAYMENT_TYPE);
            if (archetype != null) {
                setArchetype(archetype);
            }
        }
        return component;
    }
}
