/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2019 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.workspace.patient.investigation;

import nextapp.echo2.app.Color;
import nextapp.echo2.app.Component;
import org.openvpms.component.business.domain.im.act.Act;
import org.openvpms.component.service.archetype.ArchetypeService;
import org.openvpms.web.component.im.layout.LayoutContext;
import org.openvpms.web.component.im.table.DefaultDescriptorTableModel;
import org.openvpms.web.component.im.table.DescriptorTableColumn;
import org.openvpms.web.echo.style.Styles;
import org.openvpms.web.system.ServiceHelper;

/**
 * Table model for <em>act.patientInvestigationResultItem</em>.
 *
 * @author Tim Anderson
 */
public class ResultTableModel extends DefaultDescriptorTableModel<Act> {

    /**
     * The archetype service.
     */
    private final ArchetypeService service;

    /**
     * Constructs a {@link ResultTableModel}.
     *
     * @param shortNames the archetype short names. May contain wildcards
     * @param context    the layout context
     */
    public ResultTableModel(String[] shortNames, LayoutContext context) {
        super(shortNames, context, "analyteCode", "name", "result", "qualifier", "referenceRange");
        service = ServiceHelper.getArchetypeService();
    }

    /**
     * Returns a value for a given column.
     *
     * @param object the object to operate on
     * @param column the column
     * @param row    the row
     * @return the value for the column
     */
    @Override
    protected Object getValue(Act object, DescriptorTableColumn column, int row) {
        Object result;
        boolean outOfRange = service.getBean(object).getBoolean("outOfRange");
        if (column.getName().equals("result")) {
            // if the result is multi-line or long, limit it to a single line of up to 50 characters
            result = getTruncatedValue(object, column, 50);
        } else {
            result = super.getValue(object, column, row);
        }
        if (outOfRange && result instanceof Component) {
            Component component = (Component) result;
            component.setForeground(Color.RED);
            component.setStyleName(Styles.BOLD);
        }
        return result;
    }
}
