/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2016 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.workspace.workflow;

import org.openvpms.archetype.rules.patient.PatientArchetypes;
import org.openvpms.component.business.domain.im.act.Act;
import org.openvpms.web.component.app.Context;
import org.openvpms.web.component.im.edit.EditDialog;
import org.openvpms.web.component.im.edit.IMObjectEditor;
import org.openvpms.web.component.im.layout.LayoutContext;
import org.openvpms.web.component.im.util.IMObjectCreator;
import org.openvpms.web.component.im.view.Selection;
import org.openvpms.web.echo.dialog.PopupDialog;
import org.openvpms.web.echo.help.HelpContext;
import org.openvpms.web.workspace.patient.visit.VisitCRUDWindow;

import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertNotNull;
import static org.openvpms.web.test.EchoTestHelper.fireDialogButton;


/**
 * A test {@link VisitCRUDWindow}.
 *
 * @author Tim Anderson
 */
public class TestVisitCRUDWindow extends VisitCRUDWindow {

    private final List<Act> saved = new ArrayList<Act>();

    public TestVisitCRUDWindow(Context context) {
        super(context, new HelpContext("foo", null));
    }

    /**
     * Adds a note to the current visit.
     */
    public void addNote() {
        Act act = (Act) IMObjectCreator.create(PatientArchetypes.CLINICAL_NOTE);
        assertNotNull(act);
        LayoutContext context = createLayoutContext(getHelpContext());
        IMObjectEditor editor = createEditor(act, context);
        edit(editor, null);
    }

    /**
     * Edits an object.
     *
     * @param editor the object editor
     * @param path   the selection path. May be {@code null}
     * @return the edit dialog
     */
    @Override
    protected EditDialog edit(IMObjectEditor editor, List<Selection> path) {
        EditDialog dialog = super.edit(editor, path);
        fireDialogButton(dialog, PopupDialog.OK_ID);
        return dialog;
    }

    /**
     * Invoked when the object has been saved.
     *
     * @param act   the object
     * @param isNew determines if the object is a new instance
     */
    @Override
    protected void onSaved(Act act, boolean isNew) {
        super.onSaved(act, isNew);
        if (!saved.contains(act)) {
            saved.add(act);
        }
    }
}
